@@ -456,7 +456,7 @@ static void helpCallbackMarshall(newtComponent co, void * data) {
     PyGILState_STATE _state = PyGILState_Ensure();
 
     args = Py_BuildValue("(O)", data);
-    result = PyEval_CallObject(helpCallback.cb, args);
+    result = PyObject_CallObject(helpCallback.cb, args);
     Py_DECREF (args);
     Py_XDECREF(result);
 
@@ -473,10 +473,10 @@ static void suspendCallbackMarshall(void * data) {
 
     if (scs->data) {
 	args = Py_BuildValue("(O)", scs->data);
-	result = PyEval_CallObject(scs->cb, args);
+	result = PyObject_CallObject(scs->cb, args);
 	Py_DECREF (args);
     } else
-	result = PyEval_CallObject(scs->cb, NULL);
+	result = PyObject_CallObject(scs->cb, NULL);
     
     if (!result) {
 	PyErr_Print();
@@ -498,10 +498,10 @@ static void callbackMarshall(newtComponent co, void * data) {
 
     if (scs->data) {
 	args = Py_BuildValue("(O)", scs->data);
-	result = PyEval_CallObject(scs->cb, args);
+	result = PyObject_CallObject(scs->cb, args);
 	Py_DECREF (args);
     } else
-	result = PyEval_CallObject(scs->cb, NULL);
+	result = PyObject_CallObject(scs->cb, NULL);
 
     if (!result) {
 	PyErr_Print();
@@ -1096,7 +1096,11 @@ static PyObject * widget_get_radioValue(PyObject *self, void *closure)
 {
 	snackWidget *w = (snackWidget *)self;
 
-	return Py_BuildValue("i", newtRadioGetCurrent(w->co));
+#if SIZEOF_VOID_P <= SIZEOF_LONG
+	return Py_BuildValue("l", (long)newtRadioGetCurrent(w->co));
+#else
+	return Py_BuildValue("L", (long long)newtRadioGetCurrent(w->co));
+#endif
 }
 
 static void widgetDestructor(PyObject * o) {
@@ -1499,6 +1503,7 @@ MOD_INIT(_snack)
     setitemstring_decref(d, "KEY_F11", PyInt_FromLong(NEWT_KEY_F11));
     setitemstring_decref(d, "KEY_F12", PyInt_FromLong(NEWT_KEY_F12));
     setitemstring_decref(d, "KEY_ESC", PyInt_FromLong(NEWT_KEY_ESCAPE));
+    setitemstring_decref(d, "KEY_RESIZE", PyInt_FromLong(NEWT_KEY_RESIZE));
 
     setitemstring_decref(d, "FLAG_DISABLED", PyInt_FromLong(NEWT_FLAG_DISABLED));
     setitemstring_decref(d, "FLAGS_SET", PyInt_FromLong(NEWT_FLAGS_SET));
